==> huaweicloudsdkdrs-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/modify_connection_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyConnectionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'connection_id': 'str',
        'body': 'UpdateConnectionReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'connection_id': 'connection_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, connection_id=None, body=None):
        """ModifyConnectionRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。
        :type x_language: str
        :param connection_id: 连接ID
        :type connection_id: str
        :param body: Body of the ModifyConnectionRequest
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        
        

        self._x_language = None
        self._connection_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.connection_id = connection_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this ModifyConnectionRequest.

        请求语言类型。

        :return: The x_language of this ModifyConnectionRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this ModifyConnectionRequest.

        请求语言类型。

        :param x_language: The x_language of this ModifyConnectionRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def connection_id(self):
        """Gets the connection_id of this ModifyConnectionRequest.

        连接ID

        :return: The connection_id of this ModifyConnectionRequest.
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this ModifyConnectionRequest.

        连接ID

        :param connection_id: The connection_id of this ModifyConnectionRequest.
        :type connection_id: str
        """
        self._connection_id = connection_id

    @property
    def body(self):
        """Gets the body of this ModifyConnectionRequest.

        :return: The body of this ModifyConnectionRequest.
        :rtype: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ModifyConnectionRequest.

        :param body: The body of this ModifyConnectionRequest.
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyConnectionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v5/model/modify_connection_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ModifyConnectionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'connection_id': 'str',
        'body': 'UpdateConnectionReq'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'connection_id': 'connection_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, connection_id=None, body=None):
        r"""ModifyConnectionRequest

        The model defined in huaweicloud sdk

        :param x_language: 请求语言类型。
        :type x_language: str
        :param connection_id: 连接ID
        :type connection_id: str
        :param body: Body of the ModifyConnectionRequest
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        
        

        self._x_language = None
        self._connection_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.connection_id = connection_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        r"""Gets the x_language of this ModifyConnectionRequest.

        请求语言类型。

        :return: The x_language of this ModifyConnectionRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        r"""Sets the x_language of this ModifyConnectionRequest.

        请求语言类型。

        :param x_language: The x_language of this ModifyConnectionRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def connection_id(self):
        r"""Gets the connection_id of this ModifyConnectionRequest.

        连接ID

        :return: The connection_id of this ModifyConnectionRequest.
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        r"""Sets the connection_id of this ModifyConnectionRequest.

        连接ID

        :param connection_id: The connection_id of this ModifyConnectionRequest.
        :type connection_id: str
        """
        self._connection_id = connection_id

    @property
    def body(self):
        r"""Gets the body of this ModifyConnectionRequest.

        :return: The body of this ModifyConnectionRequest.
        :rtype: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ModifyConnectionRequest.

        :param body: The body of this ModifyConnectionRequest.
        :type body: :class:`huaweicloudsdkdrs.v5.UpdateConnectionReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyConnectionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
